/* Generic */
/* Common to both Standard and Dark themes */
/* Primary */
/* Secondary */
/* Specific to Dark theme */
/* Only secondary colors */
/* Project typos */
/* Headings and body text */
.title-1,
.title-2,
.title-3,
.title-4,
.title-5,
.title-6,
.body-1,
.body-2 {
  font-family: 'Source Sans Pro', Arial, sans-serif;
}
.title-1 {
  font-size: 46px;
}
.title-2 {
  font-size: 36px;
}
.title-3 {
  font-size: 30px;
}
.title-4 {
  font-size: 26px;
}
.title-5 {
  font-size: 20px;
}
.title-6 {
  font-size: 16px;
  font-weight: bold;
}
.body-1 {
  font-family: 'Source Sans Pro', Arial, sans-serif;
  font-size: 15px;
}
.body-2 {
  font-size: 15px;
}
/* SG emphasis classes */
/* Links */
a {
  font-family: 'Source Sans Pro', Arial, sans-serif;
  font-size: 15px;
  color: #E60028;
  text-decoration: none;
  cursor: pointer;
}
a:hover {
  color: #800016;
}
a:focus,
a:active {
  color: #1a0005;
}
a.inactive {
  opacity: 0.3;
}
.dark-theme a {
  color: #777;
}
.dark-theme a:hover {
  color: #444444;
}
.dark-theme a:focus,
.dark-theme a:active {
  color: #111111;
}
/* Helpers */
.uppercase {
  text-transform: uppercase;
}
.capitalize {
  text-transform: capitalize;
}
.hyphenate {
  -webkit-hyphens: auto;
  -ms-hyphens: auto;
  -moz-hyphens: auto;
  hyphens: auto;
}
.no-select {
  -webkit-user-select: none;
  /* Chrome all / Safari all */
  -moz-user-select: none;
  /* Firefox all */
  -ms-user-select: none;
  /* IE 10+ */
  user-select: none;
  /* Likely future */
}
/* Default HTML tags style */
h1 {
  font-family: 'Source Sans Pro', Arial, sans-serif;
  font-size: 46px;
}
h2 {
  font-family: 'Source Sans Pro', Arial, sans-serif;
  font-size: 36px;
}
h3 {
  font-family: 'Source Sans Pro', Arial, sans-serif;
  font-size: 30px;
}
h4 {
  font-family: 'Source Sans Pro', Arial, sans-serif;
  font-size: 26px;
}
h1,
.h1,
h2,
.h2,
h3,
.h3,
h4,
.h4 {
  margin: 5px 0;
  text-align: center;
  color: #333333;
}
.dark-theme h1,
.dark-theme .h1,
.dark-theme h2,
.dark-theme .h2,
.dark-theme h3,
.dark-theme .h3,
.dark-theme h4,
.dark-theme .h4 {
  color: #7C7F86;
}
p {
  margin: 0.5em 0 0.5em;
  word-wrap: break-word;
  -webkit-hyphens: auto;
  -ms-hyphens: auto;
  -moz-hyphens: auto;
  hyphens: auto;
}
/* Text alignment */
.center {
  text-align: center;
}
.right {
  text-align: right;
}
.pointer {
  cursor: pointer;
}
/* Quick layouting */
.margin-v-large {
  margin-top: 30px;
  margin-bottom: 30px;
}
.margin-v {
  margin-top: 20px;
  margin-bottom: 20px;
}
.margin-v-small {
  margin-top: 10px;
  margin-bottom: 10px;
}
/* Flexbox helpers */
.flexcol {
  display: flex;
  flex-flow: column nowrap;
  justify-content: space-around;
  align-items: center;
}
.ie .flexcol > * {
  width: 100%;
}
.flexrow {
  display: flex;
  flex-flow: row nowrap;
  justify-content: space-around;
  align-items: center;
}
.flexwrap {
  flex-wrap: wrap;
}
.flexcenter {
  /* Centers child elements */
  justify-content: center;
}
.flexbetween {
  /* Max space between child elements */
  justify-content: space-between;
}
.flexstart {
  /* Pull to left or top */
  justify-content: flex-start;
}
.flexend {
  /* Pull to right or bottom */
  justify-content: flex-end;
}
/* Enable .containers to contain flex children */
.container.flexrow::before,
.container-fluid.flexrow::before,
.container.flexcol::before,
.container-fluid.flexcol::before,
.container.flexrow::after,
.container-fluid.flexrow::after,
.container.flexcol::after,
.container-fluid.flexcol::after {
  content: none;
}
/* Line separator */
hr {
  border-bottom: solid 1px #CCC;
  border-right: none;
  border-left: none;
  border-top: none;
}
html {
  position: relative;
}
body {
  overflow-x: hidden;
}
.main {
  margin-top: 15px;
}
.main .nav,
.main .content {
  display: inline-block;
  vertical-align: top;
}
.main .nav {
  width: 20%;
  min-height: 100%;
  margin-top: 1px;
}
.main .content {
  width: 80%;
}
body {
  background: #F5F5F5;
}
body.dark-theme {
  background: #191E28;
}
.main {
  background: #FFFFFF;
  padding: 15px 15px;
  border: solid 1px #CCC;
  margin-left: auto;
  margin-right: auto;
}
.dark-theme .main {
  background: #0C111B;
  border-color: #444852;
}
.tile {
  margin: 7.5px;
  /* Responsive stacking -> no extra space */
}
.dark-theme .tile {
  background: #0C111B;
  color: #7C7F86;
}
.tile.with-borders {
  border: solid 1px #CCC;
}
.dark-theme .tile.with-borders {
  border-color: #444852;
}
.row + .row [class*="col-"]:nth-of-type(1) .tile {
  margin-top: 0;
}
.sg-btn {
  border: solid 1px #CCC;
  background: #F5F5F5;
  cursor: pointer;
}
.dark-theme .sg-btn {
  background: #191E28;
}
.sg-btn.active,
.sg-btn:hover {
  background-color: #DDDEDF;
}
.dark-theme .sg-btn.active,
.dark-theme .sg-btn:hover {
  background-color: #2F333E;
  color: #CCC;
}
/* Specific */
.header {
  padding: 15px;
  background: #FFFFFF;
  border-bottom: solid 1px #DDD;
}
.dark-theme .header {
  background: #0C111B;
  border-color: #444852;
}
.header .custom-title {
  color: #333333;
}
.dark-theme .header .custom-title {
  color: #CCC;
}
.header img.left-logo,
.header img.right-logo {
  margin-right: 15px;
  width: 45px;
  height: 45px;
}
.dark-theme .header img.left-logo,
.dark-theme .header img.right-logo {
  box-shadow: rgba(255, 255, 255, 0.4) 0 0 5px;
  opacity: 0.8;
}
/* Cover for loading time */
#cover {
  position: fixed;
  height: 100%;
  width: 100%;
  top: 0;
  left: 0;
  z-index: 9999;
  background: #F5F5F5;
  /* Loading icon */
}
.dark-theme #cover {
  background-color: #0C111B;
}
#cover span.fa {
  position: absolute;
  text-align: center;
  top: 0;
  bottom: 0;
  left: 0;
  right: 0;
  margin: auto;
  width: 100%;
  height: 50px;
  font-size: 50px;
  color: #333333;
}
.dark-theme #cover span.fa {
  color: #7C7F86;
}
/* Left nav */
.nav {
  background: #F5F5F5;
  border: 1px solid #CCC;
}
.dark-theme .nav {
  background: #191E28;
}
.nav .nav-tab {
  display: block;
  padding: 20px 37px 20px 15px;
  width: 100%;
  text-align: left;
  transition: 0.1s;
  font-size: 16px;
  position: relative;
  border-top: none;
  border-left: none;
  border-right: none;
}
.nav .nav-tab.active {
  background-color: #C8C8C8;
}
.dark-theme .nav .nav-tab.active {
  background-color: #2F333E;
  color: #CCC;
}
.nav .nav-tab:last-of-type {
  border-bottom: none;
}
.nav .nav-tab span.fa {
  position: absolute;
  top: 0;
  bottom: 0;
  right: 7px;
  margin: auto;
  width: 15px;
  height: 30px;
  font-size: 30px;
  color: #333333;
}
.dark-theme .nav .nav-tab span.fa {
  color: #CCC;
}
/* Right content */
.content {
  border: 1px solid #CCC;
  margin-left: -1px;
  background: #FFFFFF;
}
.dark-theme .content {
  background: #191E28;
}
.content .tab-content {
  width: 100%;
  padding: 0 15px 7.5px;
  display: none;
}
.content .tab-content.active {
  display: block;
}
.content .tab-content h2,
.content .tab-content h3,
.content .tab-content h4 {
  padding: 10px 0;
  margin: 7.5px 0;
  border-bottom: solid 1px #DDD;
}
.dark-theme .content .tab-content h2,
.dark-theme .content .tab-content h3,
.dark-theme .content .tab-content h4 {
  color: #CCC;
}
.content .tab-content .subnav {
  margin-top: 15px;
  font-size: 0;
  background: #F5F5F5;
  border: solid 1px #CCC;
}
.dark-theme .content .tab-content .subnav {
  background: #191E28;
}
.content .tab-content .subnav .subnav-tab {
  display: inline-block;
  vertical-align: middle;
  padding: 14px 16px;
  transition: 0.1s;
  font-size: 16px;
  border-top: none;
  border-left: none;
  border-bottom: none;
}
.content .tab-content .subnav .subnav-tab.active {
  background-color: #C8C8C8;
}
.dark-theme .content .tab-content .subnav .subnav-tab.active {
  background-color: #2F333E;
  color: #CCC;
}
.content .tab-content .subnav-content {
  margin-top: 7.5px;
  display: none;
}
.content .tab-content .subnav-content.active {
  display: inherit;
}
.content .tab-content .row {
  padding-left: 7.5px;
  padding-right: 7.5px;
}
.content .tab-content .row [class*="col-"] {
  padding: 0;
}
.no-margins .content .tab-content .row .tile {
  margin: 0;
}
/* Universal rules for dark theme */
.dark-theme * {
  border-color: #444852 !important;
}
/* Theme toggle button */
.theme-toggle {
  padding: 0.5em 1em;
  text-transform: uppercase;
}
.my-markdown h1,
.my-markdown h2,
.my-markdown h3,
.my-markdown h4,
.my-markdown h5,
.my-markdown h6 {
  border-bottom: 0px;
  text-align: left;
}
.my-markdown h1 {
  font-size: 36px;
}
.my-markdown h2 {
  font-size: 30px;
}
.my-markdown h3 {
  font-size: 24px;
}
.my-markdown h4 {
  font-size: 18px;
}
.my-markdown h5 {
  font-size: 17px;
}
.my-markdown h6 {
  font-size: 16px;
}
.my-markdown table {
  font-size: 16px;
  font-weight: normal;
}
.my-markdown strong {
  font-size: 16px;
  font-weight: bold;
}
